=== added file 'src/account_data.js'
--- src/account_data.js	1970-01-01 00:00:00 +0000
+++ src/account_data.js	2014-11-19 22:06:41 +0000
@@ -0,0 +1,56 @@
+/* This file is part of GPump, a Pump.io client.
+ *
+ * GPump (THE SOFTWARE) is made available under the terms and conditions of the
+ * GNU Lesser General Public Licence 3.0. A copy of the licence can be read
+ * in the file lgpl-3.0.txt in the root of this project.
+ */
+
+
+const Secret = imports.gi.Secret;
+const Lang = imports.lang;
+
+
+let _default_account_data_object = null;
+
+/** @file
+ * More information on what is going on here can be found here:
+ * https://developer.gnome.org/libsecret/unstable/js-examples.html
+ */
+
+/** @function
+ * Get the default AccountData object.
+ */
+function get_account_data () {
+  if (!_default_account_data_object) {
+    _default_account_data_object = new AccountData ();
+  }
+  return _default_account_data_object;
+}
+
+/**
+ * The libsecret schema.
+ */
+const GPUMP_SECRET_SCHEMA = new Secret.Schema ({
+  name: "org.gego.gpump.tokens",
+  flags: Secret.SchemaFlags.NONE,
+  attributes: {
+      "NickName": Secret.SchemaAttributeType.STRING, // The nickname of the user
+      "Server": Secret.SchemaAttributeType.STRING, // The server
+      "DisplayName": Secret.SchemaAttributeType.STRING
+    }
+});
+
+/** @class
+ * Class to hold the the account intformation.
+ *
+ * Do not create instances of this object, use the get_account_data function
+ * instad.
+ */
+const AccountData = Lang.Class ({
+  Name: "AccountData",
+  
+  _init: function () {
+    
+    
+  }
+});

=== added file 'src/account_ui.js'
--- src/account_ui.js	1970-01-01 00:00:00 +0000
+++ src/account_ui.js	2014-11-19 22:06:41 +0000
@@ -0,0 +1,58 @@
+/* This file is part of GPump, a Pump.io client.
+ *
+ * GPump (THE SOFTWARE) is made available under the terms and conditions of the
+ * GNU Lesser General Public Licence 3.0. A copy of the licence can be read
+ * in the file lgpl-3.0.txt in the root of this project.
+ */
+
+
+const Gtk = imports.gi.Gtk;
+const _ = imports.gettext.gettext;
+const Lang = imports.lang;
+
+/** @file
+ */
+ 
+ /** @class
+ * AccountUI is the UI that is used for handling of accounts.
+ */
+const AccountUI = Lang.Class ({
+  Name: "AccountUI",
+  Extends: Gtk.Dialog,
+  
+  _init: function () {
+    this.parent ({
+      use_header_bar: true,
+      modal: true,
+      title: _("GPump Accounts")
+    });
+    
+    this._prepare_header_bar ();
+    
+    this.show_all ();
+  },
+  
+  _prepare_header_bar: function () {
+    this.headerbar = this.get_header_bar ();
+    this.headerbar.set_show_close_button (false);
+    this.headerbar.pack_end ((this.close_btn = new Gtk.Button ({
+      label: _("close")
+    })));
+    
+    this.close_btn.connect ("clicked", Lang.bind (this, function () {
+      this.destroy ();
+    }));
+    
+    /* Install a custom style */
+    let special_btn_style_ctx = this.close_btn.get_style_context ();
+    special_btn_style_ctx.add_class ("suggested-action");
+  },
+  
+  /**
+   * add a new account to the list of accouts
+   */
+  _add_new_account: function () {
+    
+  }
+  
+});

